"use strict";
// src/generate.ts
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const fs_1 = __importDefault(require("fs"));
const toHookName_1 = require("./utils/toHookName");
const getTablesProperties_1 = require("./utils/getTablesProperties");
// Utility function to generate hook names
function generateHooks(typesPath, outputPath, supabaseClientPath) {
    console.log('Generating hooks with the following arguments:', {
        typesPath,
        outputPath,
        supabaseClientPath,
    });
    const tablesProperties = (0, getTablesProperties_1.getTablesProperties)(typesPath);
    // Iterate through table keys and generate hooks
    const hooks = [];
    for (const table of tablesProperties) {
        const tableName = table.getName();
        // Generate hooks for fetching, adding, updating, and deleting
        hooks.push(`export function ${(0, toHookName_1.toHookName)(tableName, 'Get')}(id: string) {
    return useQuery<Database['public']['Tables']['${tableName}']['Row'], Error>(
      ['${tableName}', id],
      async () => {
        const { data, error } = await supabase
          .from<Database['public']['Tables']['${tableName}']['Row']>('${tableName}')
          .select('*')
          .eq('id', id)
          .single();

        if (error) {
          throw error;
        }

        if (!data) {
          throw new Error('No data found');
        }

        return data;
      },
      {
        enabled: !!id,
      }
    );
  }`, `export function ${(0, toHookName_1.toHookName)(tableName, 'GetAll')}() {
    return useQuery<Database['public']['Tables']['${tableName}']['Row'][], Error>(['${tableName}'], async () => {
      const { data, error } = await supabase.from<Database['public']['Tables']['${tableName}']['Row']>('${tableName}').select();
      if (error) throw error;
      return data as Database['public']['Tables']['${tableName}']['Row'][];
    });
  }`, `export function ${(0, toHookName_1.toHookName)(tableName, 'Add')}() {
    const queryClient = useQueryClient();
    return useMutation((item: Database['public']['Tables']['${tableName}']['Insert']) => supabase.from<Database['public']['Tables']['${tableName}']['Row']>('${tableName}').insert(item).single(), {
      onSuccess: () => {
        queryClient.invalidateQueries('${tableName}');
      },
    });
  }`, `export function ${(0, toHookName_1.toHookName)(tableName, 'Update')}() {
    const queryClient = useQueryClient();
    return useMutation((item: { id: string; changes: Database['public']['Tables']['${tableName}']['Update'] }) => supabase.from<Database['public']['Tables']['${tableName}']['Row']>('${tableName}').update(item.changes).eq('id', item.id).single(), {
      onSuccess: () => {
        queryClient.invalidateQueries('${tableName}');
      },
    });
  }`, `export function ${(0, toHookName_1.toHookName)(tableName, 'Delete')}() {
    const queryClient = useQueryClient();
    return useMutation((id: string) => supabase.from<Database['public']['Tables']['${tableName}']['Row']>('${tableName}').delete().eq('id', id).single(), {
      onSuccess: () => {
        queryClient.invalidateQueries('${tableName}');
      },
    });
  }`);
    }
    // Create the output file content with imports and hooks
    const hooksFileContent = `
import { useMutation, useQuery, useQueryClient } from 'react-query';
import { Database } from '${typesPath}';
import { supabase } from '${supabaseClientPath}';

${hooks.join('\n\n')}
`;
    // Write the output file
    fs_1.default.writeFileSync(outputPath, hooksFileContent);
}
exports.default = generateHooks;
